@@ -30,6 +30,15 @@ test.mcs1 <- function() {
   checkEquals(9, get.atom.count(mcs))
 }
 
+test.mcs3 <- function() {
+  mols <- parse.smiles(c("c1cccc(COC(=O)NC(CC(C)C)C(=O)NC(CCc2ccccc2)C(=O)COC)c1", "c1cccc(COC(=O)NC(CC(C)C)C(=O)NCC#N)c1"))
+  lapply(mols, do.aromaticity)
+  lapply(mols, do.typing) 
+  mcs <- get.mcs(mols[[1]], mols[[2]], TRUE)
+  checkEquals("org.openscience.cdk.AtomContainer", .jclass(mcs))
+  checkEquals(21, get.atom.count(mcs))
+}
+
 test.mcs2 <- function() {
   mols <- parse.smiles(c("NCc1ccccc1OC(=N)CCN", "c1ccccc1OC(=N)"))
   lapply(mols, do.aromaticity)
